@@ -49,7 +49,9 @@ class QueueProtocol(_BinaryMessageQueueMixin, _Protocol):
 
     def connection_made(self, transport: _BaseTransport) -> None:
         """Log the connection establishment."""
-        self.logger = _getLogger(_TransportMixin(transport).logger_name())
+        self.logger = _getLogger(
+            _TransportMixin(transport).logger_name("TCP ")
+        )
         self.logger.info("Connected.")
 
     def connection_lost(self, exc: _Optional[Exception]) -> None:
@@ -76,7 +78,7 @@ class TcpConnection(_Connection, _TransportMixin):
 
         self._protocol = protocol
         self._protocol.conn = self
-        super().__init__(_getLogger(self.logger_name()))
+        super().__init__(_getLogger(self.logger_name("TCP ")))
 
     async def _await_message(self) -> _Optional[_Union[_BinaryMessage, str]]:
         """Await the next message. Return None on error or failure."""
@@ -129,7 +131,7 @@ class TcpConnection(_Connection, _TransportMixin):
         async with server:
             for socket in server.sockets:
                 LOG.info(
-                    "Started server listening on '%s'.", _sockname(socket)
+                    "Started TCP server listening on '%s'.", _sockname(socket)
                 )
             yield server
 
@@ -158,11 +160,11 @@ class TcpConnection(_Connection, _TransportMixin):
             if serving_callback is not None:
                 serving_callback(server)
 
-            LOG.info("Application starting.")
+            LOG.info("TCP Application starting.")
             await manager.manage(stop_sig)
-            LOG.info("Application stopped.")
+            LOG.info("TCP Application stopped.")
 
-        LOG.info("Server closed.")
+        LOG.info("TCP Server closed.")
 
     @classmethod
     async def create_pair(cls: _Type[T]) -> _Tuple[T, T]:
